@@ -1,4 +1,4 @@
-/*      $Id: xfwm4_plugin.c 12289 2005-01-14 11:41:37Z pollux $
+/*      $Id: xfwm4_plugin.c 18862 2005-11-15 11:58:12Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -772,26 +772,35 @@ update_theme_dir (const gchar * theme_dir, GList * theme_list)
 
     if (info)
     {
-        if (!has_decoration && !has_keybinding)
+        if (!strcmp (theme_dir, info->path))
         {
-            list = g_list_remove (list, info);
-            theme_info_free (info);
-        }
-        else if ((info->has_keybinding != has_keybinding)
-            || (info->has_decoration != has_decoration) || (info->set_layout != set_layout) || (info->set_align != set_align) || (info->set_font != set_font))
-        {
-            info->has_keybinding = has_keybinding;
-            info->has_decoration = has_decoration;
-            info->set_layout = set_layout;
-            info->set_align = set_align;
-            info->set_font = set_font;
-            info->user_writable = user_writable;
+            if (!has_decoration && !has_keybinding)
+            {
+                TRACE ("Removing %s", theme_name);
+                list = g_list_remove (list, info);
+                theme_info_free (info);
+            }
+            else if ((info->has_keybinding != has_keybinding)
+                     || (info->has_decoration != has_decoration) 
+                     || (info->set_layout != set_layout) 
+                     || (info->set_align != set_align) 
+                     || (info->set_font != set_font))
+            {
+                TRACE ("Updating %s", theme_name);
+                info->has_keybinding = has_keybinding;
+                info->has_decoration = has_decoration;
+                info->set_layout = set_layout;
+                info->set_align = set_align;
+                info->set_font = set_font;
+                info->user_writable = user_writable;
+            }
         }
     }
     else
     {
         if (has_decoration || has_keybinding)
         {
+            TRACE ("Adding %s", theme_name);
             info = g_new0 (ThemeInfo, 1);
             info->path = g_strdup (theme_dir);
             info->name = g_strdup (theme_name);
@@ -2247,19 +2256,25 @@ gboolean
 write_options (McsPlugin * mcs_plugin)
 {
     gchar *rcfile, *path;
-    gboolean result;
+    gboolean result = FALSE;
 
     path = g_build_filename ("xfce4", "mcs_settings", RCFILE1, NULL);
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);    
-    result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL1, rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL1, rcfile);
+        g_free (rcfile);
+    }
     g_free (path);
-    g_free (rcfile);
 
     path = g_build_filename ("xfce4", "mcs_settings", RCFILE2, NULL);
     rcfile = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, path, TRUE);    
-    result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL2, rcfile);
+    if (G_LIKELY (rcfile != NULL))
+    {
+        result = mcs_manager_save_channel_to_file (mcs_plugin->manager, CHANNEL2, rcfile);
+        g_free (rcfile);
+    }
     g_free (path);
-    g_free (rcfile);
 
     return result;
 }
