@@ -1,4 +1,4 @@
-/*      $Id: events.c 14291 2005-05-13 21:35:54Z olivier $
+/*      $Id: events.c 18245 2005-10-13 20:17:03Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -542,8 +542,11 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
             case KEY_MOVE_WORKSPACE_7:
             case KEY_MOVE_WORKSPACE_8:
             case KEY_MOVE_WORKSPACE_9:
-                clientRaise (c);
-                workspaceSwitch (screen_info, key - KEY_MOVE_WORKSPACE_1, c);
+                if (key - KEY_WORKSPACE_1 < screen_info->workspace_count)
+                {
+                    clientRaise (c);
+                    workspaceSwitch (screen_info, key - KEY_MOVE_WORKSPACE_1, c);
+                }
                 break;
             default:
                 break;
@@ -609,7 +612,10 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
         case KEY_WORKSPACE_7:
         case KEY_WORKSPACE_8:
         case KEY_WORKSPACE_9:
-            workspaceSwitch (screen_info, key - KEY_WORKSPACE_1, NULL);
+            if (key - KEY_WORKSPACE_1 < screen_info->workspace_count)
+            {
+                workspaceSwitch (screen_info, key - KEY_WORKSPACE_1, NULL);
+            }
             break;
         case KEY_SHORTCUT_1:
         case KEY_SHORTCUT_2:
@@ -1862,8 +1868,8 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         if (((ev->message_type == display_info->atoms[WIN_WORKSPACE]) || 
              (ev->message_type == display_info->atoms[NET_CURRENT_DESKTOP])) && (ev->format == 32))
         {
-            TRACE ("root has received a win_workspace or a net_current_desktop event");
-            if (ev->data.l[0] != screen_info->current_ws)
+            TRACE ("root has received a win_workspace or a net_current_desktop event %i", ev->data.l[0]);
+            if ((ev->data.l[0] >= 0) && (ev->data.l[0] < screen_info->workspace_count) && (ev->data.l[0] != screen_info->current_ws))
             {
                 workspaceSwitch (screen_info, ev->data.l[0], NULL);
             }
@@ -2005,7 +2011,7 @@ handleEvent (DisplayInfo *display_info, XEvent * ev)
             handleColormapNotify (display_info, (XColormapEvent *) ev);
             break;
         default:
-            if (display_info->shape && (ev->type == display_info->shape_event))
+            if ((display_info->shape) && (ev->type == display_info->shape_event))
             {
                 handleShape (display_info, (XShapeEvent *) ev);
             }
