@@ -1,8 +1,9 @@
-/*
+/*      $Id: events.h 11914 2004-08-22 22:18:50Z olivier $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +15,7 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -33,9 +34,10 @@
 #include <glib.h>
 #include <libxfcegui4/libxfcegui4.h>
 
+#include "screen.h"
 
-void handleEvent (XEvent *);
-GtkToXEventFilterStatus xfwm4_event_filter (XEvent * xevent, gpointer data);
-void initGtkCallbacks (void);
+void initMenuEventWin (void);
+XfceFilterStatus xfwm4_event_filter (XEvent * xevent, gpointer data);
+void initGtkCallbacks (ScreenInfo *);
 
 #endif /* INC_EVENTS_H */
