@@ -1,8 +1,9 @@
-/*
+/*      $Id: misc.h 12192 2004-12-09 22:44:20Z olivier $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,31 +15,28 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
-#ifndef INC_MISC_H
-#define INC_MISC_H
-
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include <sys/types.h>
-#include <sys/time.h>
 #include <X11/Xlib.h>
 #include <glib.h>
+#include "screen.h"
 
-void getMouseXY (Window, int *, int *);
-Window getMouseWindow (Window);
-GC createGC (Colormap, char *, int, XFontStruct *, int, gboolean);
-void sendClientMessage (Window, Atom, long, int);
-void MyXGrabServer (void);
-void MyXUngrabServer (void);
-gboolean MyCheckWindow(Window);
-Window setTmpEventWin (int, int, unsigned int, unsigned int, long);
-void removeTmpEventWin (Window);
-void placeSidewalks(gboolean);
+#ifndef INC_MISC_H
+#define INC_MISC_H
+
+void getMouseXY (ScreenInfo *, Window, int *, int *);
+Window getMouseWindow (ScreenInfo *, Window);
+GC createGC (ScreenInfo *, char *, int, XFontStruct *, int, gboolean);
+void sendClientMessage (ScreenInfo *, Window, int, Time);
+gboolean checkWindowOnRoot (ScreenInfo *, Window);
+void placeSidewalks(ScreenInfo *, gboolean);
+gint find_monitor_at_point (GdkScreen *screen, gint x, gint y);
 
 #endif /* INC_MISC_H */
