@@ -1,4 +1,4 @@
-/*      $Id: mypixmap.c,v 1.16 2004/08/22 22:18:50 olivier Exp $
+/*      $Id: mypixmap.c 13586 2005-04-14 21:45:55Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ xfwmPixmapCompose (XfwmPixmap * pm, gchar * dir, gchar * file)
     GdkPixbuf *alpha;
     GdkPixbuf *src;
     GdkPixmap *destw;
+    GdkVisual *gvisual;
     GdkColormap *cmap;
     GError *error = NULL;
     gint width, height;
@@ -80,33 +81,20 @@ xfwmPixmapCompose (XfwmPixmap * pm, gchar * dir, gchar * file)
     
     if (!destw)
     {
-        DBG ("Cannot get pixmap");
+        g_warning ("Cannot get pixmap");
         g_object_unref (alpha);
         return FALSE;
     }
 
-    cmap = gdk_drawable_get_colormap (destw);
-    if (cmap)
-    {
-        g_object_ref (G_OBJECT (cmap));
-    }
-    else
-    {
-        if (gdk_drawable_get_depth (destw) == 1)
-        {
-            cmap = NULL;
-        }
-        else
-        {
-            cmap = gdk_screen_get_rgb_colormap (pm->screen_info->gscr);
-            g_object_ref (G_OBJECT (cmap));
-        }
-    }
+    gvisual = gdk_screen_get_system_visual (pm->screen_info->gscr);
+    cmap = gdk_x11_colormap_foreign_new (gvisual, pm->screen_info->cmap);    
 
-    if (cmap && (gdk_colormap_get_visual (cmap)->depth != gdk_drawable_get_depth (destw)))
+    if (!cmap)
     {
-        g_object_unref (G_OBJECT (cmap));
-        cmap = NULL;
+        g_warning ("Cannot create colormap");
+        g_object_unref (alpha);
+        g_object_unref (destw);
+        return FALSE;
     }
 
     width = MIN (gdk_pixbuf_get_width (alpha), pm->width);
@@ -119,10 +107,7 @@ xfwmPixmapCompose (XfwmPixmap * pm, gchar * dir, gchar * file)
     gdk_draw_pixbuf (GDK_DRAWABLE (destw), NULL, src, 0, 0, 0, 0,
                      pm->width, pm->height, GDK_RGB_DITHER_NONE, 0, 0);                 
 
-    if (cmap)
-    {
-        g_object_unref (G_OBJECT (cmap));
-    }
+    g_object_unref (cmap);
     g_object_unref (alpha);
     g_object_unref (src);
     g_object_unref (destw);
@@ -153,10 +138,11 @@ xfwmPixmapLoad (ScreenInfo * screen_info, XfwmPixmap * pm, gchar * dir, gchar *
     g_free (filexpm);
     attr.colorsymbols = cs;
     attr.numsymbols = n;
+    attr.depth = screen_info->depth;
     attr.colormap = pm->screen_info->cmap;
     attr.closeness = 65535;
-    attr.valuemask = XpmCloseness | XpmColormap | XpmSize;
-    if (n > 0 && cs)
+    attr.valuemask = XpmCloseness | XpmColormap | XpmSize | XpmDepth;
+    if ((n > 0) && (cs != NULL))
     {
         attr.valuemask = attr.valuemask | XpmColorSymbols;
     }
