@@ -1,4 +1,4 @@
-/*      $Id: netwm.c,v 1.26 2004/12/30 22:08:37 olivier Exp $
+/*      $Id: netwm.c 18757 2005-11-07 18:32:33Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -453,7 +453,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     if ((first  == display_info->atoms[NET_WM_STATE_ABOVE]) || 
         (second == display_info->atoms[NET_WM_STATE_ABOVE]))
     {
-        if (!clientIsValidTransientOrModal (c) && !FLAG_TEST (c->flags, CLIENT_FLAG_BELOW))
+        if (!FLAG_TEST (c->flags, CLIENT_FLAG_BELOW))
         {
             if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_ABOVE))
             {
@@ -476,7 +476,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     if ((first  == display_info->atoms[NET_WM_STATE_BELOW]) || 
         (second == display_info->atoms[NET_WM_STATE_BELOW]))
     {
-        if (!clientIsValidTransientOrModal (c) && !FLAG_TEST (c->flags, CLIENT_FLAG_ABOVE))
+        if (!FLAG_TEST (c->flags, CLIENT_FLAG_ABOVE))
         {
             if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_BELOW))
             {
@@ -534,6 +534,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
             FLAG_TOGGLE (c->flags, CLIENT_FLAG_SKIP_TASKBAR);
             clientSetNetState (c);
         }
+        frameDraw (c, TRUE, FALSE);
     }
 }
 
@@ -588,10 +589,9 @@ clientUpdateFullscreenState (Client * c)
            grab focus in focus follow mouse mode. Grab the pointer to
            avoid these effects
          */
-        XGrabPointer (clientGetXDisplay (c), c->screen_info->gnome_win, FALSE, EnterWindowMask, GrabModeAsync,
-                           GrabModeAsync, None, None, CurrentTime);
-        clientConfigure (c, &wc, CWX | CWY | CWWidth | CWHeight, NO_CFG_FLAG);
-        XUngrabPointer (clientGetXDisplay (c), CurrentTime);
+        myScreenGrabPointer (c->screen_info, EnterWindowMask, None, CurrentTime);
+        clientConfigure (c, &wc, CWX | CWY | CWWidth | CWHeight, CFG_FORCE_REDRAW);
+        myScreenUngrabPointer (c->screen_info, CurrentTime);
     }
     else
     {
@@ -696,7 +696,8 @@ clientGetInitialNetWmDesktop (Client * c)
     }
     else
     {
-        if (!FLAG_TEST_ALL (c->xfwm_flags, XFWM_FLAG_SESSION_MANAGED | XFWM_FLAG_WORKSPACE_SET))
+        if (!FLAG_TEST (c->xfwm_flags, XFWM_FLAG_SESSION_MANAGED)
+            &&  !FLAG_TEST (c->xfwm_flags, XFWM_FLAG_WORKSPACE_SET))
         {
             FLAG_SET (c->xfwm_flags, XFWM_FLAG_WORKSPACE_SET);
             c->win_workspace = c->screen_info->current_ws;
@@ -996,16 +997,9 @@ clientWindowType (Client * c)
         TRACE ("Window \"%s\" is a transient or a modal", c->name);
 
         c2 = clientGetHighestTransientOrModalFor (c);
-        if (c2)
+        if ((c2) && (c->initial_layer < c2->win_layer))
         {
-            if (clientIsTransient (c))
-            {
-                c->initial_layer = c2->win_layer;
-            }
-            else if (c->initial_layer < c2->win_layer) /* clientIsModal (c) */
-            {
-                c->initial_layer = c2->win_layer;
-            }
+            c->initial_layer = c2->win_layer;
             TRACE ("Applied layer is %i", c->initial_layer);
         }
         FLAG_UNSET (c->xfwm_flags, XFWM_FLAG_HAS_HIDE | XFWM_FLAG_HAS_STICK);
