@@ -1,4 +1,4 @@
-/*      $Id: parserc.h,v 1.17 2004/09/21 19:27:01 olivier Exp $
+/*      $Id: parserc.h 13879 2005-05-02 19:59:37Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -29,14 +29,14 @@
 #include <glib.h>
 #include "settings.h"
 
-gboolean parseRc (const gchar *, const gchar *, Settings rc[]);
-gboolean checkRc (Settings rc[]);
-gchar *getValue (const gchar *, Settings rc[]);
-gboolean setValue (const gchar *, const gchar *, Settings rc[]);
-gboolean setBooleanValueFromInt (const gchar *, int, Settings rc[]);
-gboolean setIntValueFromInt (const gchar *, int, Settings rc[]);
+gboolean parseRc (const gchar *, const gchar *, Settings *);
+gboolean checkRc (Settings *);
+gchar *getValue (const gchar *, Settings *);
+gboolean setValue (const gchar *, const gchar *, Settings *);
+gboolean setBooleanValueFromInt (const gchar *, int, Settings *);
+gboolean setIntValueFromInt (const gchar *, int, Settings *);
 gchar *getSystemThemeDir (void);
 gchar *getThemeDir (const gchar *, const gchar *);
-void freeRc (Settings rc[]);
+void freeRc (Settings *);
 
 #endif /* INC_PARSERC_H */
