@@ -1,4 +1,4 @@
-/*      $Id: settings.c,v 1.122 2004/12/16 22:53:27 olivier Exp $
+/*      $Id: settings.c 13879 2005-05-02 19:59:37Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -68,15 +68,15 @@ static void              watch_cb             (Window,
                                                long, 
                                                void *);
 static void              loadRcData           (ScreenInfo *, 
-                                               Settings rc[]);
+                                               Settings *);
 static void              loadMcsData          (ScreenInfo *,
-                                               Settings rc[]);
+                                               Settings *);
 static void              loadTheme            (ScreenInfo *, 
-                                               Settings rc[]);
+                                               Settings *);
 static void              loadShortcutCmd      (ScreenInfo *, 
-                                               Settings rc[]);
+                                               Settings *);
 static gboolean          loadKeyBindings      (ScreenInfo *, 
-                                               Settings rc[]);
+                                               Settings *);
 static void              unloadTheme          (ScreenInfo *);
 static void              unloadSettings       (ScreenInfo *);
 static gboolean          reloadScreenSettings (ScreenInfo *, 
@@ -398,7 +398,7 @@ watch_cb (Window window, Bool is_start, long mask, void *cb_data)
 }
 
 static void
-loadRcData (ScreenInfo *screen_info, Settings rc[])
+loadRcData (ScreenInfo *screen_info, Settings *rc)
 {
     gchar *homedir;
     gchar *keythemevalue;
@@ -434,7 +434,7 @@ loadRcData (ScreenInfo *screen_info, Settings rc[])
 }
 
 static void
-loadMcsData (ScreenInfo *screen_info, Settings rc[])
+loadMcsData (ScreenInfo *screen_info, Settings *rc)
 {
     McsSetting *setting;
     if (screen_info->mcs_client)
@@ -621,7 +621,7 @@ loadMcsData (ScreenInfo *screen_info, Settings rc[])
 }
 
 static void
-loadTheme (ScreenInfo *screen_info, Settings rc[])
+loadTheme (ScreenInfo *screen_info, Settings *rc)
 {
     GtkWidget *widget = NULL;
     DisplayInfo *display_info = NULL;
@@ -637,8 +637,8 @@ loadTheme (ScreenInfo *screen_info, Settings rc[])
 
     rc[0].value  = get_style (widget, "fg",    "selected");
     rc[1].value  = get_style (widget, "fg",    "insensitive");
-    rc[2].value  = get_style (widget, "fg",    "selected");
-    rc[3].value  = get_style (widget, "fg",    "insensitive");
+    rc[2].value  = get_style (widget, "fg",    "normal");
+    rc[3].value  = get_style (widget, "fg",    "normal");
     rc[4].value  = get_style (widget, "bg",    "selected");
     rc[5].value  = get_style (widget, "light", "selected");
     rc[6].value  = get_style (widget, "dark",  "selected");
@@ -916,7 +916,7 @@ loadTheme (ScreenInfo *screen_info, Settings rc[])
 }
 
 static void
-loadShortcutCmd (ScreenInfo *screen_info, Settings rc[])
+loadShortcutCmd (ScreenInfo *screen_info, Settings *rc)
 {
     int i;
 
@@ -939,7 +939,7 @@ loadShortcutCmd (ScreenInfo *screen_info, Settings rc[])
 }
 
 static gboolean
-loadKeyBindings (ScreenInfo *screen_info, Settings rc[])
+loadKeyBindings (ScreenInfo *screen_info, Settings *rc)
 {
     Display *dpy;
     gchar *keytheme;
