@@ -1,4 +1,4 @@
-/*      $Id: stacking.c 12443 2005-03-27 19:32:37Z olivier $
+/*      $Id: stacking.c 18619 2005-11-03 21:58:46Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -321,7 +321,7 @@ clientRaise (Client * c)
             c2 = (Client *) index1->data;
             if (c2)
             {
-                if ((c2 != c) && clientIsTransientOrModalFor (c2, c))
+                if ((c2 != c) && clientIsTransientOrModalFor (c2, c) && (c2->win_layer <= c->win_layer))
                 {
                     transients = g_list_append (transients, c2);
                     if (sibling)
@@ -418,7 +418,8 @@ clientLower (Client * c)
         {
             client_sibling = clientGetTransient (c);
         }
-        if (!client_sibling)
+        if ((!client_sibling) || 
+            (client_sibling && (client_sibling->win_layer < c->win_layer)))
         {
             client_sibling = clientGetBottomMost (screen_info, c->win_layer, c);
         }
