@@ -1,4 +1,4 @@
-/*      $Id: startup_notification.c,v 1.20 2004/08/28 23:10:17 olivier Exp $
+/*      $Id: startup_notification.c 16044 2005-06-22 21:56:39Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -230,10 +230,8 @@ sn_client_startup_properties (Client * c)
 
             wmclass = sn_startup_sequence_get_wmclass (tmp->data);
 
-            if ((wmclass != NULL) && ((c->class.res_class
-                        && !strcmp (wmclass, c->class.res_class))
-                    || (c->class.res_name
-                        && !strcmp (wmclass, c->class.res_name))))
+            if ((wmclass != NULL) && ((c->class.res_class && !strcmp (wmclass, c->class.res_class))
+                || (c->class.res_name && !strcmp (wmclass, c->class.res_name))))
             {
                 sequence = tmp->data;
 
